@@ -153,10 +153,10 @@ struct defPolygon_t
         {}
 
     defPolygon_t()
-        : pen0(Qt::NoPen)
-        , color0(Qt::black)
+        : pen0(Qt::magenta,2)
+        , color0(Qt::magenta)
         , font(QFont("Sans",10))
-        , style0(Qt::SolidPattern)
+        , style0(Qt::BDiagPattern)
         {}
 
     QPen            pen0;
@@ -387,6 +387,7 @@ void CGarminMap::loadSkin(const QString& filename)
     /*"Scrub",                   */ dictPolygon[0x4f] = defPolygon_t(Qt::green,defaultFont,Qt::Dense5Pattern);
     /*"Tundra",                  */ dictPolygon[0x52] = defPolygon_t(Qt::lightGray,defaultFont,Qt::Dense5Pattern);
     /*"Flat",                    */ dictPolygon[0x53] = defPolygon_t(Qt::lightGray,defaultFont,Qt::Dense5Pattern);
+    /*"???",         */             dictPolygon[0x54] = defPolygon_t(Qt::NoPen,defaultFont,Qt::NoBrush);
 
     if(skinfile.open(QIODevice::ReadOnly)) {
         QRegExp re("(.*)\\.(.*):\\s+(.*)");
@@ -408,7 +409,7 @@ void CGarminMap::loadSkin(const QString& filename)
                     setSkinValue(dictPolyline[0x04],tokens[2],tokens[3]);
                 }
                 else if(tokens[1] == "Collector") {
-                    setSkinValue(dictPolyline[0x03],tokens[2],tokens[3]);
+                    setSkinValue(dictPolyline[0x05],tokens[2],tokens[3]);
                 }
                 else if(tokens[1] == "County_border") {
                     setSkinValue(dictPolyline[0x1D],tokens[2],tokens[3]);
@@ -669,6 +670,9 @@ void CGarminMap::loadSkin(const QString& filename)
                 else if(tokens[1] == "Wetland_Swamp") {
                     setSkinValue(dictPolygon[0x51],tokens[2],tokens[3]);
                 }
+                else if(tokens[1] == "Wetland_Swamp54") {
+                    setSkinValue(dictPolygon[0x54],tokens[2],tokens[3]);
+                }
                 // the left overs
                 else {
                     qDebug() << tokens;
@@ -841,8 +845,6 @@ void CGarminMap::drawBackground(QPainter * p)
         p = &paintBottom;
     }
 
-//     p->setRenderHint(QPainter::Antialiasing,true);
-
     // draw active map
     const QList<CGarminImg*>& mapFiles = gpResources->mapdb().getVisibleTiles(CGarminDBMap::eMap);
     QList<CGarminImg*>::const_iterator file = mapFiles.begin();
@@ -1026,6 +1028,11 @@ void CGarminMap::drawPolyline(quint16 type, const QPolygonF& poly, QPainter& p,
     else if ( type == 34 ) {     // Major land contour
         pen.setJoinStyle(Qt::MiterJoin);
         thickness = scale > 10.0 ? 1 : 2;
+    }
+                                 // Stream
+    else if ( type == 0x18 || type == 0x1f) {
+        pen.setJoinStyle(Qt::MiterJoin);
+        thickness = scale > 10.0 ? 2 : 3;
     }
     else {
         pen.setJoinStyle(Qt::RoundJoin);
@@ -1136,8 +1143,12 @@ void CGarminMap::drawPolygons(const subfile_desc_t& map,QPainter& p, quint8 leve
 }
 
 
-void CGarminMap::drawPolygon(const quint16 type, const QPolygonF& poly, QPainter& p, const QString& )
+void CGarminMap::drawPolygon(const quint16 type, const QPolygonF& poly, QPainter& p, const QString& label)
 {
+    if(!dictPolygon.contains(type)) {
+        qWarning() << "Unsupported polygon type:" << type << label;
+    }
+
     defPolygon_t& def = dictPolygon[type];
     p.setPen(def.pen0);
     p.setBrush(QBrush(def.color0,def.style0));
@@ -1659,7 +1670,8 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
                 p.setBrush(Qt::cyan);
                 p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
                 if(scale < 5.0) {
-                    CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());                }
+                    CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());
+                }
                 break;
         }
         return;
