@@ -90,6 +90,7 @@ void IMap::convertPt2Rad(double& u, double& v)
     v = pt.v;
 }
 
+
 void IMap::convertRad2Pt(double& u, double& v)
 {
     XY pt;
@@ -140,7 +141,6 @@ void IMap::draw(QPainter& p,bool buffered)
         drawBackground(&p);
     }
 
-
     QPoint px1(rect.toRect().bottomRight() - QPoint(100,50));
 
     // step I: get the approximate distance for 200px in the bottom right corner
@@ -159,19 +159,19 @@ void IMap::draw(QPainter& p,bool buffered)
     double a = (int)log10(d);
     double b = log10(d) - a;
 
-//     qDebug() << log10(d) << d << a << b;
+    //     qDebug() << log10(d) << d << a << b;
 
-    if(0 <= b && b < log10(3)){
+    if(0 <= b && b < log10(3)) {
         d = 1 * pow(10,a);
     }
-    else if(log10(3) < b && b < log10(5)){
+    else if(log10(3) < b && b < log10(5)) {
         d = 3 * pow(10,a);
     }
-    else{
+    else {
         d = 5 * pow(10,a);
     }
 
-//     qDebug() << "----" << d;
+    //     qDebug() << "----" << d;
 
     // step III: convert the scale length from [m] into [px]
     XY pt1, pt2;
@@ -184,7 +184,6 @@ void IMap::draw(QPainter& p,bool buffered)
     // step IV: draw the scale
     QPoint px2(px1 - QPoint(px1.x() - pt2.u,0));
 
-    p.setRenderHint(QPainter::Antialiasing,false);
     p.setPen(QPen(Qt::white, 9));
     p.drawLine(px1, px2 + QPoint(9,0));
     p.setPen(QPen(Qt::black, 7));
@@ -198,7 +197,7 @@ void IMap::draw(QPainter& p,bool buffered)
     pen.setDashPattern(pattern);
     p.setPen(pen);
     p.drawLine(px1, px2 + QPoint(9,0));
-    p.setRenderHint(QPainter::Antialiasing,true);
+
 
     QPoint px3(px2.x() + (px1.x() - px2.x())/2, px2.y());
 
